addScaleBar: addScaleBar

View source: R/addScaleBar.R

addScaleBarR Documentation

addScaleBar

Description

Add a horizontal scale bare to image

Usage

addScaleBar(
  image = NULL,
  length_per_pixel_in_um = NULL,
  distance_from_border = 20,
  number_size_factor = 1
)

Arguments

image

An array (2 or 3 dimensional array, could also be of formal class Image by package EBImage)

length_per_pixel_in_um

A number (length per pixel in um)

distance_from_border

A number (distance in pixels for the scale bar)

number_size_factor

A number (factor for resizing the number)

Details

Add a scale bar to a tiff image depending on the meta data of the czi file

Author(s)

Kai Budde


SFB-ELAINE/cellPixels documentation built on Oct. 12, 2024, 8:45 p.m.