| addScaleBar | R Documentation |
Add a horizontal scale bare to image
addScaleBar(
image = NULL,
length_per_pixel_in_um = NULL,
distance_from_border = 20,
number_size_factor = 1
)
image |
An array (2 or 3 dimensional array, could also be of formal class Image by package EBImage) |
length_per_pixel_in_um |
A number (length per pixel in um) |
distance_from_border |
A number (distance in pixels for the scale bar) |
number_size_factor |
A number (factor for resizing the number) |
Add a scale bar to a tiff image depending on the meta data of the czi file
Kai Budde
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.